@@ -1,18 +1,16 @@
-import logging
 from typing import Optional
 
 from pymobiledevice3.exceptions import PyMobileDevice3Exception, NotMountedError, UnsupportedCommandError, \
     AlreadyMountedError
 from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.services.base_service import BaseService
 
 
-class MobileImageMounterService(object):
+class MobileImageMounterService(BaseService):
     SERVICE_NAME = 'com.apple.mobile.mobile_image_mounter'
 
     def __init__(self, lockdown: LockdownClient):
-        self.logger = logging.getLogger(__name__)
-        self.lockdown = lockdown
-        self.service = self.lockdown.start_service(self.SERVICE_NAME)
+        super().__init__(lockdown, self.SERVICE_NAME)
 
     def list_images(self):
         """ Lookup mounted image by its name. """
